==> cmsmadesimple-1.8.2p0.tgz: cms/modules/FileManager/lang/ext/sk_SK.php <==
<?php
$lang['friendlyname'] = 'S&uacute;borov&yacute; manaž&eacute;r';
$lang['permission'] = 'Použitie s&uacute;borov&eacute;ho manaž&eacute;ru';
$lang['permissionadvanced'] = 'Pokročil&eacute; vyžitie s&uacute;borov&eacute;ho manaž&eacute;ru';
$lang['moddescription'] = 'Obsluha s&uacute;borov a adres&aacute;rov  v upload-filesection cmsms';
$lang['installed'] = 'S&uacute;borov&yacute; manaž&eacute;r %s nain&scaron;talovan&yacute;';
$lang['postinstall'] = 'S&uacute;borov&yacute; manaž&eacute;r bol nain&scaron;talovan&yacute;';
$lang['uninstalled'] = 'S&uacute;borov&yacute; manaž&eacute;r odin&scaron;talovan&yacute;';
$lang['really_uninstall'] = 'Ste si ist&yacute;, že chcete s&uacute;borov&yacute; manaž&eacute;r odin&scaron;talovať?';
$lang['upgraded'] = 'S&uacute;borov&yacute; manaž&eacute;r bol aktualizovan&yacute; na verziu %s';
$lang['fileview'] = 'Prehľad s&uacute;borov';
$lang['switchtofileview'] = 'Prepn&uacute;ť do prehľadu s&uacute;borov';
$lang['settings'] = 'Nastavenia';
$lang['savesettings'] = 'Uložiť nastavenia';
$lang['filename'] = 'N&aacute;zov s&uacute;boru';
$lang['fileinfo'] = 'Inform&aacute;cie o s&uacute;bore';
$lang['fileowner'] = 'Vlastn&iacute;k s&uacute;boru';
$lang['fileperms'] = 'Opr&aacute;vnenia';
$lang['filesize'] = 'Veľkosť';
$lang['filedate'] = 'D&aacute;tum';
$lang['actions'] = 'Možnosti';
$lang['delete'] = 'Odstr&aacute;niť';
$lang['notwritable'] = 'Nie je možn&eacute; zapisovať';
$lang['filetoobig'] = 'je pr&iacute;li&scaron; veľk&yacute;. Nahr&aacute;vanie zru&scaron;en&eacute;.';
$lang['unknown'] = 'Nezn&aacute;my';
$lang['fileoutsideuploads'] = 'Nem&aacute;te povolen&eacute; upravovať s&uacute;bory mimo adres&aacute;r UPLOADS (vyžaduje si nastaviť voľbu - Zapn&uacute;ť roz&scaron;&iacute;ren&yacute; m&oacute;d? v nastaveniach )';
$lang['writable'] = 'Zapisovateľny';
$lang['writeprotected'] = 'Chr&aacute;nen&eacute; pred z&aacute;pisom';
$lang['bytes'] = 'bytov';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 's&uacute;bory';
$lang['bytesin'] = 'bytov v';
$lang['in'] = 'v';
$lang['file'] = 's&uacute;bo';
$lang['fileno'] = 'Žiadny s&uacute;bor.';
$lang['subdirs'] = 'podadres&aacute;re';
$lang['subdir'] = 'podadres&aacute;r';
$lang['and'] = 'a';
$lang['confirmsingledelete'] = 'Ste si ist&yacute;?';
$lang['confirmsingledirdelete'] = 'Ste si ist&yacute;, že chcete tento adres&aacute;ro odstr&aacute;niť?';
$lang['dirtreedeletesuccess'] = 'Adres&aacute;r bol odstr&aacute;nen&yacute; vr&aacute;tane jeho obsahu .';
$lang['dirtreedeletefail'] = 'Nastala chyba pri odstraňovan&iacute; tohto adres&aacute;ra. Av&scaron;ak, nejak&yacute; jeho obsah mohol byť odstr&aacute;nen&yacute;.';
$lang['singlefiledeletesuccess'] = 'S&uacute;bor bol &uacute;spe&scaron;ne odstr&aacute;nen&yacute;';
$lang['filedeletesuccess'] = 'bol &uacute;spe&scaron;ne odstr&aacute;nen&yacute;';
$lang['singlefiledeletefail'] = 'Nastala chyba pri odstr&aacute;nen&iacute; s&uacute;boru';
$lang['filedeletefail'] = ' nebol nahrat&yacute;, nastala chyba';
$lang['singledirdeletesuccess'] = 'Adres&aacute;r bol &uacute;spe&scaron;ne odstr&aacute;nen&yacute;';
$lang['singledirdeletefail'] = 'Nastala cyhba pri odstr&aacute;ňovan&iacute; adres&aacute;ra (je pr&aacute;zdny?)';
$lang['deleteselected'] = 'Odstr&aacute;niť vybran&eacute; s&uacute;bory';
$lang['confirmselected'] = 'Ste si ist&yacute;?';
$lang['confirmdeleteselected'] = 'Ste si ist&yacute;, že chcete odstraniť vybran&eacute; s&uacute;bory?';
$lang['deleteselectedcancelled'] = 'Odstr&aacute;ňovanie vybran&yacute;ch s&uacute;borov bolo zru&scaron;en&eacute;';
$lang['recursetext'] = 'Recurz&iacute;vne do podadres&aacute;rov';
$lang['nofilesselected'] = 'Neboli vybran&eacute; žiadne s&uacute;bory';
$lang['moveselected'] = 'Presun&uacute;ť vybran&eacute; s&uacute;bory.';
$lang['copyselected'] = 'Kop&iacute;rovať vybran&eacute; s&uacute;bory';
$lang['selecttargetdir'] = 'Vybrať cieľov&yacute; adres&aacute;re pre presnunuiet/kop&iacute;rovanie';
$lang['movedto'] = 'presun&uacute;ť do';
$lang['copiedto'] = 'kop&iacute;rovať do';
$lang['couldnotmove'] = 'nem&ocirc;že byť presunut&yacute;';
$lang['couldnotcopy'] = 'nem&ocirc;že byť skop&iacute;rovan&yacute;';
$lang['rename'] = 'Premenovať';
$lang['newname'] = 'Nov&yacute; n&aacute;zov:';
$lang['renamesuccess'] = 'S&uacute;bor &uacute;spe&scaron;ne premenovan&yacute;';
$lang['renamefailure'] = 'Nastala chyba pri premenovan&iacute; s&uacute;boru';
$lang['renamecancelled'] = 'Premenovanie s&uacute;boru zr&uacute;&scaron;en&eacute;';
$lang['owner'] = 'Vlastn&iacute;k';
$lang['group'] = 'Skupina';
$lang['others'] = 'Ostatn&eacute;';
$lang['newpermissions'] = 'Nov&eacute; opr&aacute;vnenia:';
$lang['setpermissions'] = 'Nastaviť opr&aacute;vnenia';
$lang['permissionstyle'] = '&Scaron;&yacute;l opr&aacute;vnenia';
$lang['rwxstyle'] = 'rwx &scaron;t&yacute;l';
$lang['755style'] = '755 &scaron;t&yacute;l';
$lang['quickmode'] = 'Quic chmod (podobne ako 777)';
$lang['chmod'] = 'Zmeniť opr&aacute;vnenia';
$lang['chmodselected'] = 'Zmeniť opr&aacute;vnenia vybran&yacute;m s&uacute;borom.';
$lang['chmodsuccess'] = 'S&uacute;bor &uacute;spe&scaron;ne dostal nov&eacute; opr&aacute;vnenia';
$lang['chmodfailure'] = 'Zmena opr&aacute;vnen&iacute; s chybou';
$lang['chmodcancelled'] = 'Zmena opr&aacute;vnen&iacute; zru&scaron;en&aacute;';
$lang['dirchmodfailmulti'] = 'Zmena pr&aacute;v pre adres&aacute;r zlyhala,  je možn&eacute; v&scaron;ak, že pri časti obsahu v adres&aacute;ri mohlo dojsť ku zmene pr&aacute;v';
$lang['dirchmodsuccessmulti'] = 'Zmena pre adres&aacute;ra a jeho obsah prebehla v poriadku';
$lang['dirchmodsuccess'] = 'Adres&aacute;r &uacute;spe&scaron;ne dostal nov&eacute; opr&aacute;vnenia';
$lang['dirchmodfailure'] = 'Zlyhalo nastavenie opr&aacute;venen&iacute; pre adres&aacute;r';
$lang['dirnotemptyconfirm'] = 'Tento adres&aacute;r nie je pr&aacute;zdny. Skutočne ho chcete odstraniť , vr&aacute;teane podadres&aacute;rov a obsahu?';
$lang['dirtreedeletecancelled'] = 'Odstr&aacute;nenie adres&aacute;ra zru&scaron;en&eacute;';
$lang['imsure'] = 'Som si ist&yacute;';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Nahrať nov&eacute; s&uacute;bory';
$lang['unpackafterupload'] = 'Sk&uacute;siť rozbaliť s&uacute;bor po nahrat&iacute; (podporovan&eacute; s&uacute; iba tgz a v&auml;č&scaron;ina zip s&uacute;borov)?';
$lang['uploadsuccess'] = 'bol &uacute;spe&scaron;ne nahrat&yacute;';
$lang['uploadfail'] = 's chybou pri nahr&aacute;van&iacute;';
$lang['unpacksuccess'] = 'bol &uacute;spe&scaron;ne rozbalen&yacute;';
$lang['unpackfail'] = ' zlyhalo s touto chybou: ';
$lang['packfileopenfail'] = 'Nem&ocirc;že otvoriť zbalen&yacute; s&uacute;bor (form&aacute;t nie je podporovan&yacute;?)';
$lang['packfilewritefail'] = 'Nie je možn&eacute; otvoriť s&uacute;bor &amp;s pre z&aacute;pis';
$lang['containsillegalchars'] = 'N&aacute;zov s&uacute;boru obsahuje neplatn&eacute; znaky (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'S&uacute;časn&aacute;cesta';
$lang['newdirname'] = 'Vytvoriť adres&aacute;r:';
$lang['newdirsuccess'] = 'Adres&aacute;r bol &uacute;spe&scaron;ne vytvoren&yacute;';
$lang['newdirfail'] = 'Nastala chyby pri vytv&aacute;ran&iacute; adres&aacute;ra';
$lang['invalidnewdir'] = 'N&aacute;zov adres&aacute;ra nem&ocirc;že obsahovať znaky typu: /, \ and &#039;..&#039; ';
$lang['filedateformat'] = 'd. m. Y H:m:s';
$lang['iconsize'] = 'Veľkosť ikony';
$lang['smallicons'] = 'Mal&eacute; ikonky';
$lang['largeicons'] = 'Veľk&eacute; ikony';
$lang['thousanddelimiter'] = 'oddeľovač tis&iacute;ciek';
$lang['none'] = 'Žiadny ';
$lang['space'] = 'priestor';
$lang['showthumbnails'] = 'Uk&aacute;zať n&aacute;hĺady';
$lang['showthumbnailshelp'] = 'Aktiv&aacute;ciou tejto možnosti bud&uacute; obr&aacute;zky zobr&aacute;zen&eacute; so svoj&iacute;mi n&aacute;hľadmi, ak bud&uacute; vytvoren&eacute;. Vypnut&iacute;m tejto  možnosti zobraz&iacute;te kompletn&yacute; zoznam s&uacute;burou v adres&aacute;ri, vr&aacute;tane nahľadov a veľk&yacute;ch obr&aacute;zkov.';
$lang['uploadfilesto'] = 'Nahrať s&uacute;bory do:';
$lang['uploadview'] = 'Nahrať s&uacute;bor';
$lang['uploadboxes'] = 'Počet nahr&aacute;vac&iacute;ch boxov';
$lang['nothinguploaded'] = 'Nič nenahrat&eacute;';
$lang['unsupportedarchive'] = 'Nepodporovan&yacute; form&aacute;t arch&iacute;vu';
$lang['uploadmethod'] = 'Sp&ocirc;sob nahr&aacute;vania';
$lang['uploaderstandard'] = 'Klasick&yacute; html sp&ocirc;sob  (vr&aacute;tane rozbaľovania s&uacute;borov)';
$lang['enableadvanced'] = 'Zapn&uacute;ť roz&scaron;&iacute;ren&yacute; m&oacute;d?';
$lang['advancedhelp'] = 'Povol&iacute; pr&iacute;stup k celej &scaron;trukt&uacute;re cmsms, nie iba k adres&aacute;ru /uploads/ (ak je povolen&yacute;)';
$lang['showhiddenfileshelp'] = 'Iba v pr&iacute;pade roz&scaron;&iacute;ren&eacute;ho m&oacute;du';
$lang['showhiddenfiles'] = 'Uk&aacute;zať skryt&eacute; s&uacute;bory';
$lang['settingsconfirmsingledelete'] = 'Potvrdenie odstr&aacute;nenia samotn&eacute;ho s&uacute;boru?';
$lang['settingssaved'] = 'Nastavenia upraven&eacute;';
$lang['help'] = '		<h3>Čo tento modul rob&iacute;?</h3>
		<p>Tento modul umožnuje spr&aacute;vu s&uacute;borov</p>
		<h3>Ako sa použ&iacute;va?</h3>
		<p>Vyberte si v administrac&iacute;i zo sekcie Obsah položku s&uacute;borov&yacute; manaž&eacute;r</p>';
$lang['qca'] = 'P0-1608926040-1271144175783';
$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
$lang['chartbeat2'] = '87v0u4nbwegh3lki';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/FileManager/lang/ext/sk_SK.php <==
<?php
$lang['friendlyname'] = 'S&uacute;borov&yacute; manaž&eacute;r';
$lang['permission'] = 'Použitie s&uacute;borov&eacute;ho manaž&eacute;ru';
$lang['permissionadvanced'] = 'Pokročil&eacute; vyžitie s&uacute;borov&eacute;ho manaž&eacute;ru';
$lang['moddescription'] = 'Obsluha s&uacute;borov a adres&aacute;rov  v upload-filesection cmsms';
$lang['installed'] = 'S&uacute;borov&yacute; manaž&eacute;r %s nain&scaron;talovan&yacute;';
$lang['postinstall'] = 'S&uacute;borov&yacute; manaž&eacute;r bol nain&scaron;talovan&yacute;';
$lang['uninstalled'] = 'S&uacute;borov&yacute; manaž&eacute;r odin&scaron;talovan&yacute;';
$lang['really_uninstall'] = 'Ste si ist&yacute;, že chcete s&uacute;borov&yacute; manaž&eacute;r odin&scaron;talovať?';
$lang['upgraded'] = 'S&uacute;borov&yacute; manaž&eacute;r bol aktualizovan&yacute; na verziu %s';
$lang['fileview'] = 'Prehľad s&uacute;borov';
$lang['switchtofileview'] = 'Prepn&uacute;ť do prehľadu s&uacute;borov';
$lang['settings'] = 'Nastavenia';
$lang['savesettings'] = 'Uložiť nastavenia';
$lang['postletexists'] = 'Upozornenie! Pros&iacute;m odstr&aacute;nte v adres&aacute;r modules/FileManager/postlet, pretože bol s&uacute;časťou e&scaron;te star&yacute;ch verzi&iacute; syst&eacute;mu.';
$lang['filename'] = 'N&aacute;zov s&uacute;boru';
$lang['fileinfo'] = 'Inform&aacute;cie o s&uacute;bore';
$lang['fileowner'] = 'Vlastn&iacute;k s&uacute;boru';
$lang['fileperms'] = 'Opr&aacute;vnenia';
$lang['filesize'] = 'Veľkosť';
$lang['filedate'] = 'D&aacute;tum';
$lang['actions'] = 'Možnosti';
$lang['delete'] = 'Odstr&aacute;niť';
$lang['notwritable'] = 'Nie je možn&eacute; zapisovať';
$lang['afileistoobig'] = 'S&uacute;bor je pr&iacute;li&scaron; veľk&yacute;. Nahr&aacute;vanie zru&scaron;en&eacute;';
$lang['unknown'] = 'Nezn&aacute;my';
$lang['fileoutsideuploads'] = 'Nem&aacute;te povolen&eacute; upravovať s&uacute;bory mimo adres&aacute;r UPLOADS (vyžaduje si nastaviť voľbu - Zapn&uacute;ť roz&scaron;&iacute;ren&yacute; m&oacute;d? v nastaveniach )';
$lang['writable'] = 'Zapisovateľny';
$lang['writeprotected'] = 'Chr&aacute;nen&eacute; pred z&aacute;pisom';
$lang['bytes'] = 'bytov';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 's&uacute;bory';
$lang['bytesin'] = 'bytov v';
$lang['in'] = 'v';
$lang['file'] = 's&uacute;bo';
$lang['fileno'] = 'Žiadny s&uacute;bor.';
$lang['subdirs'] = 'podadres&aacute;re';
$lang['subdir'] = 'podadres&aacute;r';
$lang['and'] = 'a';
$lang['confirmsingledelete'] = 'Ste si ist&yacute;?';
$lang['confirmsingledirdelete'] = 'Ste si ist&yacute;, že chcete tento adres&aacute;ro odstr&aacute;niť?';
$lang['dirtreedeletesuccess'] = 'Adres&aacute;r bol odstr&aacute;nen&yacute; vr&aacute;tane jeho obsahu .';
$lang['dirtreedeletefail'] = 'Nastala chyba pri odstraňovan&iacute; tohto adres&aacute;ra. Av&scaron;ak, nejak&yacute; jeho obsah mohol byť odstr&aacute;nen&yacute;.';
$lang['singlefiledeletesuccess'] = 'S&uacute;bor bol &uacute;spe&scaron;ne odstr&aacute;nen&yacute;';
$lang['filedeletesuccess'] = 'bol &uacute;spe&scaron;ne odstr&aacute;nen&yacute;';
$lang['singlefiledeletefail'] = 'Nastala chyba pri odstr&aacute;nen&iacute; s&uacute;boru';
$lang['filedeletefail'] = ' nebol nahrat&yacute;, nastala chyba';
$lang['singledirdeletesuccess'] = 'Adres&aacute;r bol &uacute;spe&scaron;ne odstr&aacute;nen&yacute;';
$lang['singledirdeletefail'] = 'Nastala cyhba pri odstr&aacute;ňovan&iacute; adres&aacute;ra (je pr&aacute;zdny?)';
$lang['deleteselected'] = 'Odstr&aacute;niť vybran&eacute; s&uacute;bory';
$lang['confirmselected'] = 'Ste si ist&yacute;?';
$lang['confirmdeleteselected'] = 'Ste si ist&yacute;, že chcete odstraniť vybran&eacute; s&uacute;bory?';
$lang['deleteselectedcancelled'] = 'Odstr&aacute;ňovanie vybran&yacute;ch s&uacute;borov bolo zru&scaron;en&eacute;';
$lang['recursetext'] = 'Recurz&iacute;vne do podadres&aacute;rov';
$lang['nofilesselected'] = 'Neboli vybran&eacute; žiadne s&uacute;bory';
$lang['moveselected'] = 'Presun&uacute;ť vybran&eacute; s&uacute;bory.';
$lang['copyselected'] = 'Kop&iacute;rovať vybran&eacute; s&uacute;bory';
$lang['selecttargetdir'] = 'Vybrať cieľov&yacute; adres&aacute;re pre presnunuiet/kop&iacute;rovanie';
$lang['movedto'] = 'presun&uacute;ť do';
$lang['copiedto'] = 'kop&iacute;rovať do';
$lang['couldnotmove'] = 'nem&ocirc;že byť presunut&yacute;';
$lang['couldnotcopy'] = 'nem&ocirc;že byť skop&iacute;rovan&yacute;';
$lang['filesdeletedsuccessfully'] = '%s s&uacute;bor/y boli &uacute;spe&scaron;ne nahrat&eacute;';
$lang['filesdeletedfiled'] = '%s s&uacute;bor/y neboli odstr&aacute;nen&eacute;';
$lang['filesmovedsuccessfully'] = '%s s&uacute;bor/y bol &uacute;spe&scaron;ne presunut&eacute;';
$lang['filesmovedfailed'] = '%s s&uacute;bor/y neboli presunut&eacute;';
$lang['filescopiedsuccessfully'] = '%s s&uacute;bor/y boli &uacute;spe&scaron;ne skop&iacute;rovan&eacute;';
$lang['filescopiedfailed'] = '%s s&uacute;bor/y neboli skop&iacute;rovan&eacute;';
$lang['internalerror'] = 'Intern&aacute; chyba (znamen&aacute;, že sa stalo niečo neočak&aacute;van&eacute;, pros&iacute;m informujte n&aacute;s o tom)';
$lang['rename'] = 'Premenovať';
$lang['newname'] = 'Nov&yacute; n&aacute;zov:';
$lang['renamesuccess'] = 'S&uacute;bor &uacute;spe&scaron;ne premenovan&yacute;';
$lang['renamefailure'] = 'Nastala chyba pri premenovan&iacute; s&uacute;boru';
$lang['renamecancelled'] = 'Premenovanie s&uacute;boru zr&uacute;&scaron;en&eacute;';
$lang['owner'] = 'Vlastn&iacute;k';
$lang['group'] = 'Skupina';
$lang['others'] = 'Ostatn&eacute;';
$lang['newpermissions'] = 'Nov&eacute; opr&aacute;vnenia:';
$lang['setpermissions'] = 'Nastaviť opr&aacute;vnenia';
$lang['permissionstyle'] = '&Scaron;&yacute;l opr&aacute;vnenia';
$lang['rwxstyle'] = 'rwx &scaron;t&yacute;l';
$lang['755style'] = '755 &scaron;t&yacute;l';
$lang['quickmode'] = 'Quic chmod (podobne ako 777)';
$lang['chmod'] = 'Zmeniť opr&aacute;vnenia';
$lang['chmodselected'] = 'Zmeniť opr&aacute;vnenia vybran&yacute;m s&uacute;borom.';
$lang['chmodsuccess'] = 'S&uacute;bor &uacute;spe&scaron;ne dostal nov&eacute; opr&aacute;vnenia';
$lang['chmodfailure'] = 'Zmena opr&aacute;vnen&iacute; s chybou';
$lang['chmodcancelled'] = 'Zmena opr&aacute;vnen&iacute; zru&scaron;en&aacute;';
$lang['newuploadfailed'] = '%s s&uacute;bor/y neboli nahrat&eacute;';
$lang['newuploadsuccess'] = '%s s&uacute;bor/y boli &uacute;spe&scaron;ne nahrat';
$lang['dirchmodfailmulti'] = 'Zmena pr&aacute;v pre adres&aacute;r zlyhala,  je možn&eacute; v&scaron;ak, že pri časti obsahu v adres&aacute;ri mohlo dojsť ku zmene pr&aacute;v';
$lang['dirchmodsuccessmulti'] = 'Zmena pre adres&aacute;ra a jeho obsah prebehla v poriadku';
$lang['dirchmodsuccess'] = 'Adres&aacute;r &uacute;spe&scaron;ne dostal nov&eacute; opr&aacute;vnenia';
$lang['dirchmodfailure'] = 'Zlyhalo nastavenie opr&aacute;venen&iacute; pre adres&aacute;r';
$lang['dirnotemptyconfirm'] = 'Tento adres&aacute;r nie je pr&aacute;zdny. Skutočne ho chcete odstraniť , vr&aacute;teane podadres&aacute;rov a obsahu?';
$lang['dirtreedeletecancelled'] = 'Odstr&aacute;nenie adres&aacute;ra zru&scaron;en&eacute;';
$lang['imsure'] = 'Som si ist&yacute;';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Nahrať nov&eacute; s&uacute;bory';
$lang['unpackafterupload'] = 'Sk&uacute;siť rozbaliť s&uacute;bor po nahrat&iacute; (podporovan&eacute; s&uacute; iba tgz a v&auml;č&scaron;ina zip s&uacute;borov)?';
$lang['uploadsuccess'] = 'bol &uacute;spe&scaron;ne nahrat&yacute;';
$lang['uploadfail'] = 's chybou pri nahr&aacute;van&iacute;';
$lang['unpacksuccess'] = 'bol &uacute;spe&scaron;ne rozbalen&yacute;';
$lang['unpackfail'] = ' zlyhalo s touto chybou: ';
$lang['packfileopenfail'] = 'Nem&ocirc;že otvoriť zbalen&yacute; s&uacute;bor (form&aacute;t nie je podporovan&yacute;?)';
$lang['packfilewritefail'] = 'Nie je možn&eacute; otvoriť s&uacute;bor &amp;s pre z&aacute;pis';
$lang['afilecontainsillegalchars'] = 'N&aacute;zov s&uacute;boru obsahuje zak&aacute;zan&eacute; znaky. Nahr&aacute;vanie zru&scaron;en&eacute;.';
$lang['currentpath'] = 'S&uacute;časn&aacute;cesta';
$lang['newdirname'] = 'Vytvoriť adres&aacute;r:';
$lang['newdirsuccess'] = 'Adres&aacute;r bol &uacute;spe&scaron;ne vytvoren&yacute;';
$lang['newdirfail'] = 'Nastala chyby pri vytv&aacute;ran&iacute; adres&aacute;ra';
$lang['direxists'] = 'Adres&aacute;r už existuje.';
$lang['invalidnewdir'] = 'N&aacute;zov adres&aacute;ra nem&ocirc;že obsahovať znaky typu: /, \ and &#039;..&#039; ';
$lang['filedateformat'] = 'd. m. Y H:m:s';
$lang['iconsize'] = 'Veľkosť ikony';
$lang['smallicons'] = 'Mal&eacute; ikonky';
$lang['largeicons'] = 'Veľk&eacute; ikony';
$lang['thousanddelimiter'] = 'oddeľovač tis&iacute;ciek';
$lang['none'] = 'Žiadny ';
$lang['space'] = 'priestor';
$lang['showthumbnails'] = 'Uk&aacute;zať n&aacute;hĺady';
$lang['showthumbnailshelp'] = 'Aktiv&aacute;ciou tejto možnosti bud&uacute; obr&aacute;zky zobr&aacute;zen&eacute; so svoj&iacute;mi n&aacute;hľadmi, ak bud&uacute; vytvoren&eacute;. Vypnut&iacute;m tejto  možnosti zobraz&iacute;te kompletn&yacute; zoznam s&uacute;burou v adres&aacute;ri, vr&aacute;tane nahľadov a veľk&yacute;ch obr&aacute;zkov.';
$lang['uploadfilesto'] = 'Nahrať s&uacute;bory do:';
$lang['uploadview'] = 'Nahrať s&uacute;bor';
$lang['uploadboxes'] = 'Počet nahr&aacute;vac&iacute;ch boxov';
$lang['nothinguploaded'] = 'Nič nenahrat&eacute;';
$lang['newunsupportedarchive'] = '%s je nepodporovan&yacute; arch&iacute;v form&aacute;tu';
$lang['uploadmethod'] = 'Sp&ocirc;sob nahr&aacute;vania';
$lang['uploaderstandard'] = 'Klasick&yacute; html sp&ocirc;sob  (vr&aacute;tane rozbaľovania s&uacute;borov)';
$lang['enableadvanced'] = 'Zapn&uacute;ť roz&scaron;&iacute;ren&yacute; m&oacute;d?';
$lang['advancedhelp'] = 'Povol&iacute; pr&iacute;stup k celej &scaron;trukt&uacute;re cmsms, nie iba k adres&aacute;ru /uploads/ (ak je povolen&yacute;)';
$lang['showhiddenfileshelp'] = 'Iba v pr&iacute;pade roz&scaron;&iacute;ren&eacute;ho m&oacute;du';
$lang['showhiddenfiles'] = 'Uk&aacute;zať skryt&eacute; s&uacute;bory';
$lang['settingsconfirmsingledelete'] = 'Potvrdenie odstr&aacute;nenia samotn&eacute;ho s&uacute;boru?';
$lang['settingssaved'] = 'Nastavenia upraven&eacute;';
$lang['help'] = '		<h3>Čo tento modul rob&iacute;?</h3>
		<p>Tento modul umožnuje spr&aacute;vu s&uacute;borov</p>
		<h3>Ako sa použ&iacute;va?</h3>
		<p>Vyberte si v administrac&iacute;i zo sekcie Obsah položku s&uacute;borov&yacute; manaž&eacute;r</p>';
$lang['utmc'] = '156861353';
$lang['qca'] = 'P0-1608926040-1271144175783';
$lang['utma'] = '156861353.786385904.1271157997.1297167781.1297170856.166';
$lang['utmz'] = '156861353.1297170856.166.151.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
$lang['utmb'] = '156861353';
?>
